"use strict";
// File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.
Object.defineProperty(exports, "__esModule", { value: true });
exports.AnnotationsBasePage = exports.Annotations = void 0;
const resource_1 = require("../../resource.js");
const core_1 = require("../../core.js");
const pagination_1 = require("../../pagination.js");
class Annotations extends resource_1.APIResource {
    /**
     * Creates a new annotation.
     *
     * @example
     * ```ts
     * const annotation = await client.data.annotations.create({
     *   date: 1745438400,
     *   note: 'This is a note',
     *   sub_property_id: '123456',
     * });
     * ```
     */
    create(body, options) {
        return this._client.post('/data/v1/annotations', { body, ...options })._thenUnwrap((obj) => obj.data);
    }
    /**
     * Returns the details of a specific annotation.
     *
     * @example
     * ```ts
     * const annotation = await client.data.annotations.retrieve(
     *   '182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e',
     * );
     * ```
     */
    retrieve(annotationId, options) {
        return this._client.get(`/data/v1/annotations/${annotationId}`, options)._thenUnwrap((obj) => obj.data);
    }
    /**
     * Updates an existing annotation.
     *
     * @example
     * ```ts
     * const annotation = await client.data.annotations.update(
     *   '182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e',
     *   {
     *     date: 1745438400,
     *     note: 'This is a note',
     *     sub_property_id: '123456',
     *   },
     * );
     * ```
     */
    update(annotationId, body, options) {
        return this._client.patch(`/data/v1/annotations/${annotationId}`, { body, ...options })._thenUnwrap((obj) => obj.data);
    }
    list(query = {}, options) {
        if ((0, core_1.isRequestOptions)(query)) {
            return this.list({}, query);
        }
        return this._client.getAPIList('/data/v1/annotations', AnnotationsBasePage, { query, ...options });
    }
    /**
     * Deletes an annotation.
     *
     * @example
     * ```ts
     * await client.data.annotations.delete(
     *   '182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e',
     * );
     * ```
     */
    delete(annotationId, options) {
        return this._client.delete(`/data/v1/annotations/${annotationId}`, {
            ...options,
            headers: { Accept: '*/*', ...options?.headers },
        });
    }
}
exports.Annotations = Annotations;
class AnnotationsBasePage extends pagination_1.BasePage {
}
exports.AnnotationsBasePage = AnnotationsBasePage;
Annotations.AnnotationsBasePage = AnnotationsBasePage;
//# sourceMappingURL=annotations.js.map