// File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.
import { APIResource } from "../../resource.mjs";
import { isRequestOptions } from "../../core.mjs";
import { BasePage } from "../../pagination.mjs";
export class TranscriptionVocabularies extends APIResource {
    /**
     * Create a new Transcription Vocabulary.
     *
     * @example
     * ```ts
     * const transcriptionVocabulary =
     *   await client.video.transcriptionVocabularies.create({
     *     phrases: [
     *       'Mux',
     *       'Live Stream',
     *       'Playback ID',
     *       'video encoding',
     *     ],
     *     name: 'Mux API Vocabulary',
     *   });
     * ```
     */
    create(body, options) {
        return this._client.post('/video/v1/transcription-vocabularies', { body, ...options })._thenUnwrap((obj) => obj.data);
    }
    /**
     * Retrieves the details of a Transcription Vocabulary that has previously been
     * created. Supply the unique Transcription Vocabulary ID and Mux will return the
     * corresponding Transcription Vocabulary information. The same information is
     * returned when creating a Transcription Vocabulary.
     *
     * @example
     * ```ts
     * const transcriptionVocabulary =
     *   await client.video.transcriptionVocabularies.retrieve(
     *     'TRANSCRIPTION_VOCABULARY_ID',
     *   );
     * ```
     */
    retrieve(transcriptionVocabularyId, options) {
        return this._client.get(`/video/v1/transcription-vocabularies/${transcriptionVocabularyId}`, options)._thenUnwrap((obj) => obj.data);
    }
    /**
     * Updates the details of a previously-created Transcription Vocabulary. Updates to
     * Transcription Vocabularies are allowed while associated live streams are active.
     * However, updates will not be applied to those streams while they are active.
     *
     * @example
     * ```ts
     * const transcriptionVocabulary =
     *   await client.video.transcriptionVocabularies.update(
     *     'TRANSCRIPTION_VOCABULARY_ID',
     *     {
     *       phrases: ['Mux', 'Live Stream', 'RTMP', 'Stream Key'],
     *       name: 'Mux API Vocabulary - Updated',
     *     },
     *   );
     * ```
     */
    update(transcriptionVocabularyId, body, options) {
        return this._client.put(`/video/v1/transcription-vocabularies/${transcriptionVocabularyId}`, {
            body,
            ...options,
        })._thenUnwrap((obj) => obj.data);
    }
    list(query = {}, options) {
        if (isRequestOptions(query)) {
            return this.list({}, query);
        }
        return this._client.getAPIList('/video/v1/transcription-vocabularies', TranscriptionVocabulariesBasePage, { query, ...options });
    }
    /**
     * Deletes a Transcription Vocabulary. The Transcription Vocabulary's ID will be
     * disassociated from any live streams using it. Transcription Vocabularies can be
     * deleted while associated live streams are active. However, the words and phrases
     * in the deleted Transcription Vocabulary will remain attached to those streams
     * while they are active.
     *
     * @example
     * ```ts
     * await client.video.transcriptionVocabularies.delete(
     *   'TRANSCRIPTION_VOCABULARY_ID',
     * );
     * ```
     */
    delete(transcriptionVocabularyId, options) {
        return this._client.delete(`/video/v1/transcription-vocabularies/${transcriptionVocabularyId}`, {
            ...options,
            headers: { Accept: '*/*', ...options?.headers },
        });
    }
}
export class TranscriptionVocabulariesBasePage extends BasePage {
}
TranscriptionVocabularies.TranscriptionVocabulariesBasePage = TranscriptionVocabulariesBasePage;
//# sourceMappingURL=transcription-vocabularies.mjs.map