// File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.
import { APIResource } from "../../resource.mjs";
import { isRequestOptions } from "../../core.mjs";
import { BasePage } from "../../pagination.mjs";
export class Uploads extends APIResource {
    /**
     * Creates a new direct upload, through which video content can be uploaded for
     * ingest to Mux.
     *
     * @example
     * ```ts
     * const upload = await client.video.uploads.create({
     *   cors_origin: 'https://example.com/',
     *   new_asset_settings: { playback_policies: ['public'] },
     * });
     * ```
     */
    create(body, options) {
        return this._client.post('/video/v1/uploads', { body, ...options })._thenUnwrap((obj) => obj.data);
    }
    /**
     * Fetches information about a single direct upload in the current environment.
     *
     * @example
     * ```ts
     * const upload = await client.video.uploads.retrieve(
     *   'abcd1234',
     * );
     * ```
     */
    retrieve(uploadId, options) {
        return this._client.get(`/video/v1/uploads/${uploadId}`, options)._thenUnwrap((obj) => obj.data);
    }
    list(query = {}, options) {
        if (isRequestOptions(query)) {
            return this.list({}, query);
        }
        return this._client.getAPIList('/video/v1/uploads', UploadsBasePage, { query, ...options });
    }
    /**
     * Cancels a direct upload and marks it as cancelled. If a pending upload finishes
     * after this request, no asset will be created. This request will only succeed if
     * the upload is still in the `waiting` state.
     *
     * @example
     * ```ts
     * const upload = await client.video.uploads.cancel(
     *   'abcd1234',
     * );
     * ```
     */
    cancel(uploadId, options) {
        return this._client.put(`/video/v1/uploads/${uploadId}/cancel`, options)._thenUnwrap((obj) => obj.data);
    }
}
export class UploadsBasePage extends BasePage {
}
Uploads.UploadsBasePage = UploadsBasePage;
//# sourceMappingURL=uploads.mjs.map